
"""pylintfileheader module"""

from __future__ import absolute_import
from pylintfileheader import plugin, file_header_checker  # noqa: F401


register = plugin.register # pylint: disable=invalid-name



import re
import sys

from pylint.checkers import BaseChecker
from pylint.interfaces import IRawChecker

# pylint: disable=anomalous-backslash-in-string


class FileHeaderChecker(BaseChecker):
    __implements__ = IRawChecker

    name = 'pylintfileheader'

    msgs = {
        'C5001': (
            'File header should match regex "%s"',
            'invalid-file-header',
            'Used when the file header does not match the '
            'regex configured in the `file-header` option.'
        )
    }

    options = (
        (
            'file-header',
            {
                'default': None,
                'type': 'string',
                'metavar': '<REGEXP>',
                'help': 'The file header that should be on top of a file.',
            }
        ),
    )

    def process_module(self, node):
        """Process the astroid node stream."""
        if self.config.file_header:
            if sys.version_info[0] < 3:
                pattern = re.compile(
                    '\A' + self.config.file_header, re.LOCALE | re.MULTILINE)
            else:
                # The use of re.LOCALE is discouraged in python 3
                pattern = re.compile(
                    '\A' + self.config.file_header, re.MULTILINE)

            content = None
            with node.stream() as stream:
                # Explicit decoding required by python 3
                content = stream.read().decode('utf-8')

            matches = pattern.findall(content)

            if len(matches) != 1:
                self.add_message('invalid-file-header', 1,
                                 args=self.config.file_header)



from os import path

from setuptools import find_packages, setup

with open(path.join(path.abspath(path.dirname(__file__)), 'README.md'), 'r') as rf:
    LONG_DESCRIPTION = rf.read()

setup(
    # PEP8: Packages should also have short, all-lowercase names, the use of underscores is discouraged
    name='pylintfileheader',
    version='0.0.1',
    packages=find_packages(exclude=['*test']),
    description='Enables pylint to force a consistent file header.',
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    url='https://github.com/HaaLeo/pylint-file-header',
    author='Leo Hanisch',
    license='MIT',
    package_data={'pylintfileheader': ['ThirdPartyNotices.txt']},
    install_requires=[],
    project_urls={
        'Issue Tracker': 'https://github.com/HaaLeo/pylint-file-header/issues',
        'Changelog': 'https://github.com/HaaLeo/pylint-file-header/blob/master/CHANGELOG.md'
    },
    python_requires='>=2.7',
    keywords=[
        'pylintfileheader',
        'pylint',
        'file',
        'module',
        'header'
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ]
)
